@@ -6,7 +6,7 @@
 # ----------------------------------------------------------------------
 #  AUTHOR: Mark L. Ulferts               EMAIL: mulferts@spd.dsccc.com
 #
-#  @(#) $Id: iwidgets.tcl.in,v 1.3 2001/08/07 19:56:47 smithc Exp $
+#  @(#) $Id: iwidgets.tcl.in,v 1.8 2017/07/07 19:06:40 dgp Exp $
 # ----------------------------------------------------------------------
 #                Copyright (c) 1995  Mark L. Ulferts
 # ======================================================================
@@ -14,18 +14,28 @@
 # redistribution of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 
 package require Tcl 8.0
-package require Tk
-package require itcl 3.3
-package require itk 3.3
+package require Tk 8.0
+package require Itcl 4.0
+if {[string length [package provide Itk]] == 0} {
+    package forget Itk
+    package forget itk
+}
+package require Itk [string index 4.0 0]
 
 namespace eval ::iwidgets {
     namespace export *
 
     variable library [file dirname [info script]]
-    variable version 4.0.1
+    variable version 4.1.1
+
+    lappend auto_path $iwidgets::library
+    variable subdir
+    foreach subdir {generic scripts} {
+	if {[file isdirectory [file join $iwidgets::library $subdir]]} {
+	    lappend auto_path [file join $iwidgets::library $subdir]
+	}
+    }
+    unset subdir
 }
 
-lappend auto_path $iwidgets::library \
-		  [file join $iwidgets::library generic] \
-		  [file join $iwidgets::library scripts]
 package provide Iwidgets $iwidgets::version
